@@ -2,7 +2,7 @@
 /*
  *  Authors: Jeffrey Stedfast <fejj@ximian.com>
  *
- *  Copyright 2001-2002 Ximian, Inc. (www.ximian.com)
+ *  Copyright 2001-2004 Ximian, Inc. (www.ximian.com)
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -24,19 +24,19 @@
 #ifndef __GMIME_FILTER_FROM_H__
 #define __GMIME_FILTER_FROM_H__
 
+#include <gmime/gmime-filter.h>
+
 #ifdef __cplusplus
 extern "C" {
 #pragma }
 #endif /* __cplusplus */
 
-#include <gmime/gmime-filter.h>
-
 #define GMIME_TYPE_FILTER_FROM            (g_mime_filter_from_get_type ())
-#define GMIME_FILTER_FROM(obj)            (GMIME_CHECK_CAST ((obj), GMIME_TYPE_FILTER_FROM, GMimeFilterFrom))
-#define GMIME_FILTER_FROM_CLASS(klass)    (GMIME_CHECK_CLASS_CAST ((klass), GMIME_TYPE_FILTER_FROM, GMimeFilterFromClass))
-#define GMIME_IS_FILTER_FROM(obj)         (GMIME_CHECK_TYPE ((obj), GMIME_TYPE_FILTER_FROM))
-#define GMIME_IS_FILTER_FROM_CLASS(klass) (GMIME_CHECK_CLASS_TYPE ((klass), GMIME_TYPE_FILTER_FROM))
-#define GMIME_FILTER_FROM_GET_CLASS(obj)  (GMIME_CHECK_GET_CLASS ((obj), GMIME_TYPE_FILTER_FROM, GMimeFilterFromClass))
+#define GMIME_FILTER_FROM(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), GMIME_TYPE_FILTER_FROM, GMimeFilterFrom))
+#define GMIME_FILTER_FROM_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), GMIME_TYPE_FILTER_FROM, GMimeFilterFromClass))
+#define GMIME_IS_FILTER_FROM(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GMIME_TYPE_FILTER_FROM))
+#define GMIME_IS_FILTER_FROM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GMIME_TYPE_FILTER_FROM))
+#define GMIME_FILTER_FROM_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), GMIME_TYPE_FILTER_FROM, GMimeFilterFromClass))
 
 typedef struct _GMimeFilterFrom GMimeFilterFrom;
 typedef struct _GMimeFilterFromClass GMimeFilterFromClass;
