@@ -36,10 +36,11 @@
 #include "zentimer.h"
 #endif
 
-/*#define TEST_PRESERVE_HEADERS
+/*#define TEST_RAW_HEADER*/
+#define TEST_PRESERVE_HEADERS
 #define TEST_GET_BODY
-#define PRINT_MIME_STRUCT*/
-#define TEST_WRITE_TO_STREAM
+#define PRINT_MIME_STRUCT
+/*#define TEST_WRITE_TO_STREAM*/
 
 void
 print_depth (int depth)
@@ -111,6 +112,16 @@ test_parser (GMimeStream *stream)
 	/*fprintf (stdout, "Result should match previous MIME message dump\n\n%s\n", text);*/
 	g_free (text);
 	
+#ifdef TEST_RAW_HEADER
+	{
+		char *raw;
+		
+		raw = g_mime_message_get_headers (message);
+		fprintf (stdout, "\nTesting raw headers...\n\n%s\n", raw);
+		g_free (raw);
+	}
+#endif
+	
 #ifdef TEST_PRESERVE_HEADERS
 	{
 		GMimeStream *stream;
@@ -141,7 +152,6 @@ test_parser (GMimeStream *stream)
 	
 #ifdef TEST_WRITE_TO_STREAM
 	stream = g_mime_stream_fs_new (2);
-	g_mime_message_set_header (message, "Simple", "text");
 	g_mime_object_write_to_stream (GMIME_OBJECT (message), stream);
 	g_mime_stream_flush (stream);
 	GMIME_STREAM_FS (stream)->fd = -1;
